<template>
    <div
        element-loading-text="数据加载中..."
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)"
        v-loading.fullscreen.lock="loading"
    >
        <el-dialog
            v-dialogDrag
            :title="type + '考核设置'"
            :visible="visible"
            :before-close="handleClose"
            :close-on-click-modal="false"
            v-if="visible"
            width="50%"
            top="6vh"
            :class="[loading ? 'dialog-box' : '']"
        >
            <div>
                <el-form
                    ref="form"
                    :rules="rules"
                    :model="formData"
                    label-width="100px"
                >
                    <el-row>
                        <el-col :span="12">
                            <el-form-item label="考核对象" prop="target">
                                <el-select
                                    style="width: 100%"
                                    stylEventRegistration="width: 100%"
                                    v-model="formData.target"
                                    @change="changeTarget"
                                    clearable
                                    placeholder="请选择考核对象"
                                >
                                    <el-option
                                        v-for="item in khdxList"
                                        :key="item.value"
                                        :label="item.name"
                                        :value="item.value"
                                    >
                                    </el-option>
                                </el-select>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item label="考核类型">
                                <el-select
                                    style="width: 100%"
                                    stylEventRegistration="width: 100%"
                                    v-model="formData.type"
                                    clearable
                                    placeholder="请选择考核类型"
                                >
                                    <el-option
                                        v-for="item in khlxList"
                                        :key="item.value"
                                        :label="item.name"
                                        :value="item.value"
                                    >
                                    </el-option>
                                </el-select>
                            </el-form-item>
                        </el-col>
                    </el-row>
                    <el-row>
                        <el-col :span="12">
                            <el-form-item label="考核方式" prop="way">
                                <el-select
                                    style="width: 100%"
                                    stylEventRegistration="width: 100%"
                                    v-model="formData.way"
                                    clearable
                                    placeholder="请选择考核方式"
                                >
                                    <el-option
                                        v-for="item in khfsList"
                                        :key="item.value"
                                        :label="item.name"
                                        :value="item.value"
                                    >
                                    </el-option>
                                </el-select>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item label="考核标准">
                                <el-input
                                    clearable
                                    v-model="formData.standard"
                                    placeholder="请输入考核标准"
                                ></el-input>
                            </el-form-item>
                        </el-col>
                    </el-row>
                    <el-row>
                        <el-col :span="24">
                            <el-form-item label="备注">
                                <el-input
                                    v-model="formData.memo"
                                    type="textarea"
                                />
                            </el-form-item>
                        </el-col>
                    </el-row>
                </el-form>
            </div>
            <div
                slot="footer"
                class="dialog-footer"
                :style="loading ? 'position: relative;z-index: -1;' : ''"
            >
                <el-button @click="handleClose">取消</el-button>
                <el-button
                    type="primary"
                    @click="handleSave"
                    :loading="btnLoading"
                    >确定</el-button
                >
            </div>
        </el-dialog>
    </div>
</template>
        
<script>
import examineSetting from '@/api/Comprehensive/examineSetting'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
    props: {},
    name: 'examineSettingDialog',
    components: {},
    data() {
        return {
            visible: false,
            loading: false,
            rules: {
                standard: [
                    {
                        required: true,
                        message: '请输入考核标准',
                        trigger: 'change',
                    },
                ],
                target: [
                    {
                        required: true,
                        message: '请选择考核对象',
                        trigger: 'change',
                    },
                ],
                type: [
                    {
                        required: true,
                        message: '请选择考核类型',
                        trigger: 'change',
                    },
                ],
                way: [
                    {
                        required: true,
                        message: '请选择考核方式',
                        tirgger: 'change',
                    },
                ],
            },
            type: '新增',
            formData: {},
            btnLoading: false,
            khfsList: [], // 考核方式
            khdxList: [], // 考核对象
            khlxList: [], // 考核类型
        }
    },
    created() {
        this.khfsList = dictUtils.getDictItemsFromCache('khfs')
        this.khdxList = dictUtils.getDictItemsFromCache('khdx')
    },
    methods: {
        open(data) {
            this.formData = {
                target: null,
                type: null,
                standard: null,
                way: null,
                memo:null
            }
            this.visible = true
            this.type = '新增'
        },
        edit(id) {
            this.formData = {}
            this.visible = true
            this.type = '编辑'
            examineSetting.dataQueryById(id, (res) => {
                this.formData = res
            })
        },
        handleClose() {
            this.formData = {
                target: null,
                type: null,
                standard: null,
                way: null,
                memo:null
            }
            this.visible = false
        },
        resetForm(formName) {
            this.$refs.form.resetFields()
        },
        //保存
        handleSave() {
            this.$refs.form.validate((valid) => {
                if (valid) {
                    this.btnLoading = true
                    let method
                    if (this.type === '新增') {
                        method = examineSetting.dataAdd
                    } else {
                        method = examineSetting.editQuery
                    }
                    method(this.formData, (response) => {
                        if (response.state) {
                            this.$notify({
                                type: 'success',
                                message: this.type + '成功',
                                duration: 2000,
                            })
                            this.handleClose()
                            this.$emit('getData')
                        } else {
                            this.$message.warning(response.message)
                        }
                        this.btnLoading = false
                    })
                } else {
                    this.$notify({
                        type: 'warning',
                        message: '请完善表单信息！',
                        duration: 2000,
                    })
                }
            })
        },
        // 改变考核对象
        changeTarget(val) {
            this.khlxList = []
            this.formData.type = null
            this.khdxList.forEach((it) => {
                if (it.value === val && it.lowerDic) {
                    this.khlxList = it.lowerDic.sjfl
                }
            })
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .square-select {
    display: none;
}
/deep/.el-dialog__wrapper {
    overflow: hidden;
}

.dialog-footer {
    display: flex;
    justify-content: flex-end;
}

//加载遮罩
/deep/.el-dialog__body {
    box-sizing: border-box;

    .el-loading-parent--relative {
        max-height: inherit;
    }
}
</style>